----------------------------------------------------------------------------------
-- Company:
-- Engineer:
--
-- Create Date: 01/16/2015 10:32:46 AM
-- Design Name:
-- Module Name: dyplo_fifo_32_to_64_tb - Behavioral
-- Project Name:
-- Target Devices:
-- Tool Versions:
-- Description:
--
-- Dependencies:
--
-- Revision:
-- Revision 0.01 - File Created
-- Additional Comments:
--
----------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use ieee.math_real.all;

entity dyplo_fifo_32_to_64_tb is
end dyplo_fifo_32_to_64_tb;

architecture testbench of dyplo_fifo_32_to_64_tb is

  component dyplo_fifo_32_to_64
  generic(
    FIFO_DEPTH            : integer := 256;
    FIFO_TYPE             : string  := "DISTRIBUTED"
  );
  port(
    fifo_clk              : in  std_logic;
    fifo_rst              : in  std_logic;
    fifo_wdata            : in  std_logic_vector(31 downto 0);
    fifo_wr               : in  std_logic;
    fifo_flush_in          : in   std_logic;
    fifo_rdata            : out std_logic_vector(63 downto 0);
    fifo_rdata_complete    : out std_logic;
    fifo_rd               : in  std_logic;
    fifo_flush_out        : out std_logic;
    fifo_empty            : out std_logic;
    fifo_full             : out std_logic;
    fifo_vacant            : out std_logic_vector(11 downto 0);
    fifo_occupied         : out std_logic_vector(11 downto 0)
  );
  end component;

  signal clk              : std_logic := '0';
  signal rst              : std_logic := '1';

  signal wdata            : std_logic_vector(31 downto 0) := (others => '0');
  signal write            : std_logic := '0';
  signal flush_in         : std_logic := '0';

  signal rdata            : std_logic_vector(63 downto 0);
  signal rdata_complete   : std_logic;
  signal read             : std_logic := '0';
  signal flush_out        : std_logic;

  signal empty            : std_logic;
  signal full             : std_logic;
  signal vacant           : std_logic_vector(11 downto 0);
  signal occupied         : std_logic_vector(11 downto 0);

begin

  process(clk)
  begin
      clk <= not clk after 20 ns;
  end process;

  process
  begin
    wait for 120 ns;
    rst <= '0';

    wait until falling_edge(clk);

    for i in 0 to 4 loop
      write <= '1';
      wait until falling_edge(clk);
      wdata <= std_logic_vector(unsigned(wdata) + 1);
    end loop;

    write <= '0';
    wait until falling_edge(clk);

    for i in 0 to 4 loop
      write <= '1';
      wait until falling_edge(clk);
      wdata <= std_logic_vector(unsigned(wdata) + 1);
    end loop;

    write <= '0';
    wait until falling_edge(clk);

    flush_in  <= '1';
    wait until flush_out = '1';
    wait until falling_edge(clk);

    for i in 0 to 4 loop
      read <= '1';
      wait until falling_edge(clk);
    end loop;

    read <= '0';
    flush_in <= '0';

-- FIRST STAGE TEST DONE

    wait until falling_edge(clk);

    for i in 0 to 4 loop
      write <= '1';
      wait until falling_edge(clk);
      wdata <= std_logic_vector(unsigned(wdata) + 1);
    end loop;

    write <= '0';
    wait until falling_edge(clk);

    for i in 0 to 3 loop
      write <= '1';
      wait until falling_edge(clk);
      wdata <= std_logic_vector(unsigned(wdata) + 1);
    end loop;

    write <= '0';
    wait until falling_edge(clk);

    flush_in  <= '1';
    wait until flush_out = '1';
    wait until falling_edge(clk);

    for i in 0 to 4 loop
      read <= '1';
      wait until falling_edge(clk);
    end loop;

    read      <= '0';
    flush_in  <= '0';

-- SECOND STAGE TEST DONE

    wait until falling_edge(clk);
    write <= '1';

    wait until falling_edge(clk);
    write     <= '0';
    flush_in  <= '1';

    wait until flush_out = '1';

    wait until falling_edge(clk);
    read  <=  '1';
    wait until falling_edge(clk);
    read      <= '0';
    flush_in  <= '0';

    wait until falling_edge(clk);

    for i in 0 to 9 loop
      write <= '1';
      wait until falling_edge(clk);
      wdata <= std_logic_vector(unsigned(wdata) + 1);
    end loop;

    for i in 0 to 4 loop
      read <= '1';
      wait until falling_edge(clk);
      wdata <= std_logic_vector(unsigned(wdata) + 1);
    end loop;

    read  <= '0';
    write <= '0';


    wait;

  end process;


  fifo : dyplo_fifo_32_to_64
  generic map(
    FIFO_DEPTH            => 32,
    FIFO_TYPE             => "DISTRIBUTED"
  )
  port map(
    fifo_clk              => clk,
    fifo_rst              => rst,
    fifo_wdata            => wdata,
    fifo_wr               => write,
    fifo_flush_in         => flush_in,
    fifo_rdata            => rdata,
    fifo_rdata_complete   => rdata_complete,
    fifo_rd               => read,
    fifo_flush_out        => flush_out,
    fifo_empty            => empty,
    fifo_full             => full,
    fifo_vacant           => vacant,
    fifo_occupied         => occupied
  );


end testbench;
