-- ----------------------------------------------------------------------------
-- Copyright Message
-- ----------------------------------------------------------------------------
--
-- Topic Embedded Systems confidential and proprietary.
-- COPYRIGHT (c) 2009 Topic Embedded Systems B.V.
--
-- All rights are reserved. Reproduction or dissemination
-- in whole or in part is prohibited without the prior written
-- consent of the copyright holder.
--
-- ----------------------------------------------------------------------------
-- Design Information
-- ----------------------------------------------------------------------------
--
-- File : tb_stim_reader.m.vhd
--
-- Author : $Author$
--
-- Organisation : Topic Embedded Systems
--
-- Date : $Date$
--
-- Revision : $Revision$
--
-- Project : Auto Test
--
-- Description : This unit reads commands from a stimuli file that are send to
--               slaves (or drivers) in the test environment. A log file is
--               generated that reports all events and errors.
-- ----------------------------------------------------------------------------
-- Design Notes
-- ----------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use std.textio.all;

use work.tb_env_pkg.all;

entity tb_stim_reader is
generic(
  STIM_FILE_NAME  : string := ""
);
port (
  cmd_out         : out   cmd_record;
  cmd_accept_in   : in    std_logic;
  eof             : out   std_logic
);
end tb_stim_reader;

----------------------------------------------------------------------------------------------------------------------------------------------------------------
architecture behaviour of tb_stim_reader is

  file stim_file            : text;  -- main test file
begin

  p_read_stim_file: process
    variable v_stim_file_status : file_open_status;                     --file open status stimuli file
    variable v_stim_line        : line;                                 --store single line from stimuli file
    variable v_word_array       : word_type(CMD_WORD_DEPTH-1 downto 0); --store word out of line
    variable v_size_array       : size_type(CMD_WORD_DEPTH-1 downto 0); --store size of word
    variable v_empty_line       : boolean;                              --line is empty
    variable v_comment_line     : boolean;                              --line consist only of comments
    variable v_word_cnt         : integer;                              --number of words in line
    variable v_line_cnt         : integer;                              --line count

  begin

    eof <= '0';

    file_open(v_stim_file_status, stim_file, STIM_FILE_NAME, read_mode);
    if not(v_stim_file_status = OPEN_OK) then
        eof <= '1';
        wait;
    end if;
    cmd_out.stim_file(1 to STIM_FILE_NAME'high) <= STIM_FILE_NAME;

    --read line from stimuli file
    while not endfile(stim_file) loop
      for i in 0 to (CMD_WORD_DEPTH-1) loop
        v_size_array(i) := 0;
      end loop;

      readline(stim_file,v_stim_line);
      v_line_cnt := v_line_cnt + 1;
      cmd_out.line_cnt <= v_line_cnt;
      --read data from line
      proc_split_line(
        line_buf      =>  v_stim_line,
        word_array    =>  v_word_array,
        size_array    =>  v_size_array,
        word_cnt      =>  v_word_cnt,
        empty_line    =>  v_empty_line,
        comment_line  =>  v_comment_line
      );

      if (not(v_empty_line) and not(v_comment_line)) then --skip empty or comment line
        if (v_word_array(0)(1 to 4) = "wait") then
          wait for read_time(v_word_array(1)(1 to v_size_array(1)) & ' ' & v_word_array(2)(1 to v_size_array(2)));
        else --set command on output
          cmd_out.word <= v_word_array;
          cmd_out.size <= v_size_array;
          cmd_out.cnt <= v_word_cnt;
          cmd_out.valid <= true;
          wait until (cmd_accept_in = '1');
          cmd_out.valid <= false;
          wait until (cmd_accept_in = '0');
        end if;
      end if;
    end loop;

    file_close(stim_file);
    eof <= '1';
    wait;
  end process p_read_stim_file;

end architecture behaviour;

