
################################################################
# This is a generated script based on design: tdkz_trd
#
# Though there are limitations about the generated script,
# the main purpose of this utility is to make learning
# IP Integrator Tcl commands easier.
################################################################

namespace eval _tcl {
proc get_script_folder {} {
   set script_path [file normalize [info script]]
   set script_folder [file dirname $script_path]
   return $script_folder
}
}
variable script_folder
set script_folder [_tcl::get_script_folder]

################################################################
# Check if script is running in correct Vivado version.
################################################################
set scripts_vivado_version 2019.2
set current_vivado_version [version -short]

if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
   puts ""
   common::send_msg_id "BD_TCL-1002" "WARNING" "This script was generated using Vivado <$scripts_vivado_version> without IP versions in the create_bd_cell commands, but is now being run in <$current_vivado_version> of Vivado. There may have been major IP version changes between Vivado <$scripts_vivado_version> and <$current_vivado_version>, which could impact the parameter settings of the IPs."

}

################################################################
# START
################################################################

# To test this script, run the following commands from Vivado Tcl console:
# source tdkz_trd_script.tcl

# If there is no project opened, this script will create a
# project, but make sure you do not have an existing project
# <./myproj/project_1.xpr> in the current working folder.

set list_projs [get_projects -quiet]
if { $list_projs eq "" } {
   create_project project_1 myproj -part xc7z030sbg485-1
}


# CHANGE DESIGN NAME HERE
variable design_name
set design_name tdkz_trd

# If you do not already have an existing IP Integrator design open,
# you can create a design using the following command:
#    create_bd_design $design_name

# Creating design if needed
set errMsg ""
set nRet 0

set cur_design [current_bd_design -quiet]
set list_cells [get_bd_cells -quiet]

if { ${design_name} eq "" } {
   # USE CASES:
   #    1) Design_name not set

   set errMsg "Please set the variable <design_name> to a non-empty value."
   set nRet 1

} elseif { ${cur_design} ne "" && ${list_cells} eq "" } {
   # USE CASES:
   #    2): Current design opened AND is empty AND names same.
   #    3): Current design opened AND is empty AND names diff; design_name NOT in project.
   #    4): Current design opened AND is empty AND names diff; design_name exists in project.

   if { $cur_design ne $design_name } {
      common::send_msg_id "BD_TCL-001" "INFO" "Changing value of <design_name> from <$design_name> to <$cur_design> since current design is empty."
      set design_name [get_property NAME $cur_design]
   }
   common::send_msg_id "BD_TCL-002" "INFO" "Constructing design in IPI design <$cur_design>..."

} elseif { ${cur_design} ne "" && $list_cells ne "" && $cur_design eq $design_name } {
   # USE CASES:
   #    5) Current design opened AND has components AND same names.

   set errMsg "Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 1
} elseif { [get_files -quiet ${design_name}.bd] ne "" } {
   # USE CASES: 
   #    6) Current opened design, has components, but diff names, design_name exists in project.
   #    7) No opened design, design_name exists in project.

   set errMsg "Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 2

} else {
   # USE CASES:
   #    8) No opened design, design_name not in project.
   #    9) Current opened design, has components, but diff names, design_name not in project.

   common::send_msg_id "BD_TCL-003" "INFO" "Currently there is no design <$design_name> in project, so creating one..."

   create_bd_design $design_name

   common::send_msg_id "BD_TCL-004" "INFO" "Making design <$design_name> as current_bd_design."
   current_bd_design $design_name

}

common::send_msg_id "BD_TCL-005" "INFO" "Currently the variable <design_name> is equal to \"$design_name\"."

if { $nRet != 0 } {
   catch {common::send_msg_id "BD_TCL-114" "ERROR" $errMsg}
   return $nRet
}

set bCheckIPsPassed 1
##################################################################
# CHECK IPs
##################################################################
set bCheckIPs 1
if { $bCheckIPs == 1 } {
   set list_check_ips "\ 
analog.com:user:axi_dmac:*\
xilinx.com:ip:axi_gpio:*\
analog.com:user:axi_hdmi_rx:*\
analog.com:user:axi_hdmi_tx:*\
analog.com:user:axi_spdif_tx:*\
xilinx.com:ip:axi_vdma:*\
topicproducts.com:ip:axis_2_lcd:*\
xilinx.com:ip:c_counter_binary:*\
xilinx.com:ip:clk_wiz:*\
xilinx.com:ip:xlconstant:*\
topicembeddedproducts.com:dyplo:dyplo_axi:*\
xilinx.com:ip:gmii_to_rgmii:*\
xilinx.com:ip:proc_sys_reset:*\
xilinx.com:ip:processing_system7:*\
xilinx.com:ip:util_vector_logic:*\
xilinx.com:ip:xlconcat:*\
xilinx.com:ip:xlslice:*\
"

   set list_ips_missing ""
   common::send_msg_id "BD_TCL-006" "INFO" "Checking if the following IPs exist in the project's IP catalog: $list_check_ips ."

   foreach ip_vlnv $list_check_ips {
      set ip_obj [get_ipdefs -all $ip_vlnv]
      if { $ip_obj eq "" } {
         lappend list_ips_missing $ip_vlnv
      }
   }

   if { $list_ips_missing ne "" } {
      catch {common::send_msg_id "BD_TCL-115" "ERROR" "The following IPs are not found in the IP Catalog:\n  $list_ips_missing\n\nResolution: Please add the repository containing the IP(s) to the project." }
      set bCheckIPsPassed 0
   }

}

if { $bCheckIPsPassed != 1 } {
  common::send_msg_id "BD_TCL-1003" "WARNING" "Will not continue with creation of design due to the error(s) above."
  return 3
}

##################################################################
# DESIGN PROCs
##################################################################



# Procedure to create entire design; Provide argument to make
# procedure reusable. If parentCell is "", will use root.
proc create_root_design { parentCell } {

  variable script_folder
  variable design_name

  if { $parentCell eq "" } {
     set parentCell [get_bd_cells /]
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj


  # Create interface ports
  set DDR [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:ddrx_rtl:1.0 DDR ]

  set FIXED_IO [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_processing_system7:fixedio_rtl:1.0 FIXED_IO ]

  set MDIO_PHY [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:mdio_rtl:1.0 MDIO_PHY ]

  set PMODs [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 PMODs ]

  set RGMII [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:rgmii_rtl:1.0 RGMII ]


  # Create ports
  set CLK125_NDO [ create_bd_port -dir I -type clk -freq_hz 125000000 CLK125_NDO ]
  set LEDS [ create_bd_port -dir O -from 4 -to 0 LEDS ]
  set UART1_CTSN [ create_bd_port -dir I UART1_CTSN ]
  set UART1_RTSN [ create_bd_port -dir O UART1_RTSN ]
  set UART1_RX [ create_bd_port -dir I UART1_RX ]
  set UART1_TX [ create_bd_port -dir O UART1_TX ]
  set backlight_en [ create_bd_port -dir O backlight_en ]
  set backlight_pwm [ create_bd_port -dir O backlight_pwm ]
  set button_s2 [ create_bd_port -dir I button_s2 ]
  set button_s3 [ create_bd_port -dir I button_s3 ]
  set cdce_y4_clk [ create_bd_port -dir I -type clk -freq_hz 165000000 cdce_y4_clk ]
  set clock98mhz [ create_bd_port -dir I -type clk -freq_hz 98304000 clock98mhz ]
  set eth_int_n [ create_bd_port -dir I -type intr eth_int_n ]
  set_property -dict [ list \
   CONFIG.SENSITIVITY {LEVEL_LOW} \
 ] $eth_int_n
  set eth_reset_n [ create_bd_port -dir O -from 0 -to 0 -type rst eth_reset_n ]
  set hdmi_in_clk [ create_bd_port -dir I -type clk -freq_hz 165000000 hdmi_in_clk ]
  set hdmi_in_data [ create_bd_port -dir I -from 23 -to 0 hdmi_in_data ]
  set hdmi_in_de [ create_bd_port -dir I hdmi_in_de ]
  set hdmi_in_hs [ create_bd_port -dir I hdmi_in_hs ]
  set hdmi_in_int_n [ create_bd_port -dir I -type intr hdmi_in_int_n ]
  set_property -dict [ list \
   CONFIG.SENSITIVITY {LEVEL_LOW} \
 ] $hdmi_in_int_n
  set hdmi_in_rst_n [ create_bd_port -dir O -from 0 -to 0 -type rst hdmi_in_rst_n ]
  set hdmi_in_vs [ create_bd_port -dir I hdmi_in_vs ]
  set hdmi_out_clk [ create_bd_port -dir O -from 0 -to 0 hdmi_out_clk ]
  set hdmi_out_data [ create_bd_port -dir O -from 23 -to 0 hdmi_out_data ]
  set hdmi_out_de [ create_bd_port -dir O hdmi_out_de ]
  set hdmi_out_hs [ create_bd_port -dir O hdmi_out_hs ]
  set hdmi_out_spdif [ create_bd_port -dir O hdmi_out_spdif ]
  set hdmi_out_spdif_clk [ create_bd_port -dir I -type clk -freq_hz 12000000 hdmi_out_spdif_clk ]
  set_property -dict [ list \
   CONFIG.CLK_DOMAIN {/clk_wiz_0_clk_out1} \
   CONFIG.PHASE {0.0} \
 ] $hdmi_out_spdif_clk
  set hdmi_out_vs [ create_bd_port -dir O hdmi_out_vs ]
  set lvds_channel_0_n [ create_bd_port -dir O lvds_channel_0_n ]
  set lvds_channel_0_p [ create_bd_port -dir O lvds_channel_0_p ]
  set lvds_channel_1_n [ create_bd_port -dir O lvds_channel_1_n ]
  set lvds_channel_1_p [ create_bd_port -dir O lvds_channel_1_p ]
  set lvds_channel_2_n [ create_bd_port -dir O lvds_channel_2_n ]
  set lvds_channel_2_p [ create_bd_port -dir O lvds_channel_2_p ]
  set lvds_clk_n [ create_bd_port -dir O lvds_clk_n ]
  set lvds_clk_p [ create_bd_port -dir O lvds_clk_p ]
  set pmod2_int [ create_bd_port -dir I pmod2_int ]
  set pmod2_ns9 [ create_bd_port -dir O -from 0 -to 0 pmod2_ns9 ]
  set pmod2_ns10 [ create_bd_port -dir O -from 0 -to 0 pmod2_ns10 ]
  set pmod2_rst [ create_bd_port -dir O -from 0 -to 0 pmod2_rst ]
  set pmod2_spi_miso [ create_bd_port -dir I pmod2_spi_miso ]
  set pmod2_spi_mosi [ create_bd_port -dir O pmod2_spi_mosi ]
  set pmod2_spi_sck [ create_bd_port -dir O -type clk pmod2_spi_sck ]
  set pmod2_spi_ss [ create_bd_port -dir O pmod2_spi_ss ]
  set touch_irq_n [ create_bd_port -dir I -type intr touch_irq_n ]
  set_property -dict [ list \
   CONFIG.SENSITIVITY {LEVEL_LOW} \
 ] $touch_irq_n
  set user_led [ create_bd_port -dir O -from 0 -to 0 -type data user_led ]

  # Create instance: axi_dmac_0, and set properties
  set axi_dmac_0 [ create_bd_cell -type ip -vlnv analog.com:user:axi_dmac axi_dmac_0 ]
  set_property -dict [ list \
   CONFIG.C_AXI_SLICE_DEST {1} \
   CONFIG.C_AXI_SLICE_SRC {1} \
   CONFIG.C_CYCLIC {0} \
   CONFIG.C_DMA_LENGTH_WIDTH {14} \
   CONFIG.C_SYNC_TRANSFER_START {1} \
 ] $axi_dmac_0

  # Create instance: axi_gpio_0, and set properties
  set axi_gpio_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_gpio axi_gpio_0 ]
  set_property -dict [ list \
   CONFIG.C_ALL_INPUTS_2 {0} \
   CONFIG.C_ALL_OUTPUTS {1} \
   CONFIG.C_GPIO2_WIDTH {16} \
   CONFIG.C_GPIO_WIDTH {5} \
   CONFIG.C_IS_DUAL {1} \
 ] $axi_gpio_0

  # Create instance: axi_hdmi_rx_0, and set properties
  set axi_hdmi_rx_0 [ create_bd_cell -type ip -vlnv analog.com:user:axi_hdmi_rx axi_hdmi_rx_0 ]

  # Create instance: axi_hdmi_tx_0, and set properties
  set axi_hdmi_tx_0 [ create_bd_cell -type ip -vlnv analog.com:user:axi_hdmi_tx axi_hdmi_tx_0 ]

  # Create instance: axi_mem_intercon, and set properties
  set axi_mem_intercon [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect axi_mem_intercon ]
  set_property -dict [ list \
   CONFIG.NUM_MI {1} \
 ] $axi_mem_intercon

  # Create instance: axi_mem_intercon_1, and set properties
  set axi_mem_intercon_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect axi_mem_intercon_1 ]
  set_property -dict [ list \
   CONFIG.ENABLE_ADVANCED_OPTIONS {0} \
   CONFIG.NUM_MI {1} \
   CONFIG.NUM_SI {2} \
   CONFIG.S00_HAS_DATA_FIFO {2} \
   CONFIG.S01_HAS_DATA_FIFO {2} \
   CONFIG.STRATEGY {2} \
 ] $axi_mem_intercon_1

  # Create instance: axi_mem_intercon_2, and set properties
  set axi_mem_intercon_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect axi_mem_intercon_2 ]
  set_property -dict [ list \
   CONFIG.NUM_MI {1} \
   CONFIG.NUM_SI {1} \
 ] $axi_mem_intercon_2

  # Create instance: axi_spdif_tx_0, and set properties
  set axi_spdif_tx_0 [ create_bd_cell -type ip -vlnv analog.com:user:axi_spdif_tx axi_spdif_tx_0 ]
  set_property -dict [ list \
   CONFIG.C_DMA_TYPE {1} \
 ] $axi_spdif_tx_0

  # Create instance: axi_vdma_0, and set properties
  set axi_vdma_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_vdma axi_vdma_0 ]
  set_property -dict [ list \
   CONFIG.c_include_s2mm {0} \
   CONFIG.c_m_axis_mm2s_tdata_width {64} \
   CONFIG.c_mm2s_genlock_mode {0} \
   CONFIG.c_mm2s_max_burst_length {16} \
   CONFIG.c_use_mm2s_fsync {1} \
 ] $axi_vdma_0

  # Create instance: axi_vdma_1, and set properties
  set axi_vdma_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_vdma axi_vdma_1 ]
  set_property -dict [ list \
   CONFIG.c_include_s2mm {0} \
   CONFIG.c_m_axis_mm2s_tdata_width {64} \
   CONFIG.c_mm2s_genlock_mode {0} \
   CONFIG.c_mm2s_linebuffer_depth {1024} \
   CONFIG.c_mm2s_max_burst_length {16} \
   CONFIG.c_num_fstores {1} \
   CONFIG.c_use_mm2s_fsync {1} \
 ] $axi_vdma_1

  # Create instance: axis_2_lcd_0, and set properties
  set axis_2_lcd_0 [ create_bd_cell -type ip -vlnv topicproducts.com:ip:axis_2_lcd axis_2_lcd_0 ]

  # Create instance: c_counter_binary_0, and set properties
  set c_counter_binary_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:c_counter_binary c_counter_binary_0 ]
  set_property -dict [ list \
   CONFIG.Output_Width {27} \
 ] $c_counter_binary_0

  # Create instance: clk_wiz_0, and set properties
  set clk_wiz_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:clk_wiz clk_wiz_0 ]
  set_property -dict [ list \
   CONFIG.CLKOUT1_REQUESTED_OUT_FREQ {51.200} \
 ] $clk_wiz_0

  # Create instance: constant_one, and set properties
  set constant_one [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant constant_one ]
  set_property -dict [ list \
   CONFIG.CONST_VAL {1} \
 ] $constant_one

  # Create instance: dyplo_axi_0, and set properties
  set dyplo_axi_0 [ create_bd_cell -type ip -vlnv topicembeddedproducts.com:dyplo:dyplo_axi dyplo_axi_0 ]
  set_property -dict [ list \
   CONFIG.CONNECT_LANES {4} \
   CONFIG.CPU_TO_FPGA_STREAMS {4} \
   CONFIG.DMA_AXI_ID_WIDTH {4} \
   CONFIG.DMA_NODES {1} \
   CONFIG.FIXED_NODES {0} \
   CONFIG.MONITOR {true} \
   CONFIG.PR_NODES {0} \
 ] $dyplo_axi_0

  # Create instance: gmii_to_rgmii_0, and set properties
  set gmii_to_rgmii_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:gmii_to_rgmii gmii_to_rgmii_0 ]
  set_property -dict [ list \
   CONFIG.C_PHYADDR {8} \
   CONFIG.RGMII_TXC_SKEW {2} \
   CONFIG.SupportLevel {Include_Shared_Logic_in_Core} \
 ] $gmii_to_rgmii_0

  # Create instance: gnd, and set properties
  set gnd [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant gnd ]
  set_property -dict [ list \
   CONFIG.CONST_VAL {0} \
 ] $gnd

  # Create instance: proc_sys_reset, and set properties
  set proc_sys_reset [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset proc_sys_reset ]
  set_property -dict [ list \
   CONFIG.C_AUX_RESET_HIGH {0} \
 ] $proc_sys_reset

  # Create instance: processing_system7_1, and set properties
  set processing_system7_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:processing_system7 processing_system7_1 ]
  set_property -dict [ list \
   CONFIG.PCW_ACT_APU_PERIPHERAL_FREQMHZ {666.666687} \
   CONFIG.PCW_ACT_CAN_PERIPHERAL_FREQMHZ {10.000000} \
   CONFIG.PCW_ACT_DCI_PERIPHERAL_FREQMHZ {10.158730} \
   CONFIG.PCW_ACT_ENET0_PERIPHERAL_FREQMHZ {125.000000} \
   CONFIG.PCW_ACT_ENET1_PERIPHERAL_FREQMHZ {10.000000} \
   CONFIG.PCW_ACT_FPGA0_PERIPHERAL_FREQMHZ {100.000000} \
   CONFIG.PCW_ACT_FPGA1_PERIPHERAL_FREQMHZ {150.000000} \
   CONFIG.PCW_ACT_FPGA2_PERIPHERAL_FREQMHZ {200.000000} \
   CONFIG.PCW_ACT_FPGA3_PERIPHERAL_FREQMHZ {10.000000} \
   CONFIG.PCW_ACT_PCAP_PERIPHERAL_FREQMHZ {200.000000} \
   CONFIG.PCW_ACT_QSPI_PERIPHERAL_FREQMHZ {200.000000} \
   CONFIG.PCW_ACT_SDIO_PERIPHERAL_FREQMHZ {50.000000} \
   CONFIG.PCW_ACT_SMC_PERIPHERAL_FREQMHZ {10.000000} \
   CONFIG.PCW_ACT_SPI_PERIPHERAL_FREQMHZ {200.000000} \
   CONFIG.PCW_ACT_TPIU_PERIPHERAL_FREQMHZ {200.000000} \
   CONFIG.PCW_ACT_TTC0_CLK0_PERIPHERAL_FREQMHZ {111.111115} \
   CONFIG.PCW_ACT_TTC0_CLK1_PERIPHERAL_FREQMHZ {111.111115} \
   CONFIG.PCW_ACT_TTC0_CLK2_PERIPHERAL_FREQMHZ {111.111115} \
   CONFIG.PCW_ACT_TTC1_CLK0_PERIPHERAL_FREQMHZ {111.111115} \
   CONFIG.PCW_ACT_TTC1_CLK1_PERIPHERAL_FREQMHZ {111.111115} \
   CONFIG.PCW_ACT_TTC1_CLK2_PERIPHERAL_FREQMHZ {111.111115} \
   CONFIG.PCW_ACT_UART_PERIPHERAL_FREQMHZ {100.000000} \
   CONFIG.PCW_ACT_WDT_PERIPHERAL_FREQMHZ {111.111115} \
   CONFIG.PCW_ARMPLL_CTRL_FBDIV {40} \
   CONFIG.PCW_CAN_PERIPHERAL_DIVISOR0 {1} \
   CONFIG.PCW_CAN_PERIPHERAL_DIVISOR1 {1} \
   CONFIG.PCW_CLK0_FREQ {100000000} \
   CONFIG.PCW_CLK1_FREQ {150000000} \
   CONFIG.PCW_CLK2_FREQ {200000000} \
   CONFIG.PCW_CLK3_FREQ {10000000} \
   CONFIG.PCW_CPU_CPU_PLL_FREQMHZ {1333.333} \
   CONFIG.PCW_CPU_PERIPHERAL_DIVISOR0 {2} \
   CONFIG.PCW_DCI_PERIPHERAL_DIVISOR0 {15} \
   CONFIG.PCW_DCI_PERIPHERAL_DIVISOR1 {7} \
   CONFIG.PCW_DDRPLL_CTRL_FBDIV {32} \
   CONFIG.PCW_DDR_DDR_PLL_FREQMHZ {1066.667} \
   CONFIG.PCW_DDR_PERIPHERAL_DIVISOR0 {2} \
   CONFIG.PCW_DDR_RAM_HIGHADDR {0x3FFFFFFF} \
   CONFIG.PCW_ENET0_ENET0_IO {EMIO} \
   CONFIG.PCW_ENET0_GRP_MDIO_ENABLE {1} \
   CONFIG.PCW_ENET0_GRP_MDIO_IO {EMIO} \
   CONFIG.PCW_ENET0_PERIPHERAL_CLKSRC {External} \
   CONFIG.PCW_ENET0_PERIPHERAL_DIVISOR0 {1} \
   CONFIG.PCW_ENET0_PERIPHERAL_DIVISOR1 {1} \
   CONFIG.PCW_ENET0_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_ENET0_PERIPHERAL_FREQMHZ {1000 Mbps} \
   CONFIG.PCW_ENET0_RESET_ENABLE {0} \
   CONFIG.PCW_ENET1_PERIPHERAL_DIVISOR0 {1} \
   CONFIG.PCW_ENET1_PERIPHERAL_DIVISOR1 {1} \
   CONFIG.PCW_ENET1_RESET_ENABLE {0} \
   CONFIG.PCW_ENET_RESET_ENABLE {1} \
   CONFIG.PCW_ENET_RESET_SELECT {Share reset pin} \
   CONFIG.PCW_EN_CLK0_PORT {1} \
   CONFIG.PCW_EN_CLK1_PORT {1} \
   CONFIG.PCW_EN_CLK2_PORT {1} \
   CONFIG.PCW_EN_EMIO_ENET0 {1} \
   CONFIG.PCW_EN_EMIO_GPIO {1} \
   CONFIG.PCW_EN_EMIO_MODEM_UART1 {1} \
   CONFIG.PCW_EN_EMIO_PJTAG {0} \
   CONFIG.PCW_EN_EMIO_SPI0 {1} \
   CONFIG.PCW_EN_EMIO_UART0 {0} \
   CONFIG.PCW_EN_EMIO_UART1 {1} \
   CONFIG.PCW_EN_ENET0 {1} \
   CONFIG.PCW_EN_GPIO {1} \
   CONFIG.PCW_EN_I2C0 {1} \
   CONFIG.PCW_EN_I2C1 {1} \
   CONFIG.PCW_EN_MODEM_UART1 {1} \
   CONFIG.PCW_EN_PJTAG {1} \
   CONFIG.PCW_EN_QSPI {1} \
   CONFIG.PCW_EN_RST0_PORT {1} \
   CONFIG.PCW_EN_SDIO0 {1} \
   CONFIG.PCW_EN_SPI0 {1} \
   CONFIG.PCW_EN_UART0 {1} \
   CONFIG.PCW_EN_UART1 {1} \
   CONFIG.PCW_EN_USB0 {1} \
   CONFIG.PCW_FCLK0_PERIPHERAL_DIVISOR0 {4} \
   CONFIG.PCW_FCLK0_PERIPHERAL_DIVISOR1 {3} \
   CONFIG.PCW_FCLK1_PERIPHERAL_DIVISOR0 {4} \
   CONFIG.PCW_FCLK1_PERIPHERAL_DIVISOR1 {2} \
   CONFIG.PCW_FCLK2_PERIPHERAL_DIVISOR0 {3} \
   CONFIG.PCW_FCLK2_PERIPHERAL_DIVISOR1 {2} \
   CONFIG.PCW_FCLK3_PERIPHERAL_DIVISOR0 {1} \
   CONFIG.PCW_FCLK3_PERIPHERAL_DIVISOR1 {1} \
   CONFIG.PCW_FCLK_CLK0_BUF {TRUE} \
   CONFIG.PCW_FCLK_CLK1_BUF {TRUE} \
   CONFIG.PCW_FCLK_CLK2_BUF {TRUE} \
   CONFIG.PCW_FPGA0_PERIPHERAL_FREQMHZ {100} \
   CONFIG.PCW_FPGA1_PERIPHERAL_FREQMHZ {150} \
   CONFIG.PCW_FPGA2_PERIPHERAL_FREQMHZ {200} \
   CONFIG.PCW_FPGA_FCLK0_ENABLE {1} \
   CONFIG.PCW_FPGA_FCLK1_ENABLE {1} \
   CONFIG.PCW_FPGA_FCLK2_ENABLE {1} \
   CONFIG.PCW_FPGA_FCLK3_ENABLE {0} \
   CONFIG.PCW_GPIO_EMIO_GPIO_ENABLE {1} \
   CONFIG.PCW_GPIO_EMIO_GPIO_IO {32} \
   CONFIG.PCW_GPIO_EMIO_GPIO_WIDTH {32} \
   CONFIG.PCW_GPIO_MIO_GPIO_ENABLE {1} \
   CONFIG.PCW_GPIO_MIO_GPIO_IO {MIO} \
   CONFIG.PCW_I2C0_GRP_INT_ENABLE {0} \
   CONFIG.PCW_I2C0_I2C0_IO {MIO 50 .. 51} \
   CONFIG.PCW_I2C0_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_I2C0_RESET_ENABLE {0} \
   CONFIG.PCW_I2C1_GRP_INT_ENABLE {0} \
   CONFIG.PCW_I2C1_I2C1_IO {MIO 52 .. 53} \
   CONFIG.PCW_I2C1_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_I2C1_RESET_ENABLE {0} \
   CONFIG.PCW_I2C_PERIPHERAL_FREQMHZ {111.111115} \
   CONFIG.PCW_I2C_RESET_ENABLE {1} \
   CONFIG.PCW_I2C_RESET_SELECT {Share reset pin} \
   CONFIG.PCW_IOPLL_CTRL_FBDIV {36} \
   CONFIG.PCW_IO_IO_PLL_FREQMHZ {1200.000} \
   CONFIG.PCW_IRQ_F2P_INTR {1} \
   CONFIG.PCW_MIO_0_DIRECTION {inout} \
   CONFIG.PCW_MIO_0_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_0_PULLUP {enabled} \
   CONFIG.PCW_MIO_0_SLEW {slow} \
   CONFIG.PCW_MIO_10_DIRECTION {inout} \
   CONFIG.PCW_MIO_10_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_10_PULLUP {enabled} \
   CONFIG.PCW_MIO_10_SLEW {slow} \
   CONFIG.PCW_MIO_11_DIRECTION {inout} \
   CONFIG.PCW_MIO_11_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_11_PULLUP {enabled} \
   CONFIG.PCW_MIO_11_SLEW {slow} \
   CONFIG.PCW_MIO_12_DIRECTION {inout} \
   CONFIG.PCW_MIO_12_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_12_PULLUP {enabled} \
   CONFIG.PCW_MIO_12_SLEW {slow} \
   CONFIG.PCW_MIO_13_DIRECTION {inout} \
   CONFIG.PCW_MIO_13_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_13_PULLUP {enabled} \
   CONFIG.PCW_MIO_13_SLEW {slow} \
   CONFIG.PCW_MIO_14_DIRECTION {inout} \
   CONFIG.PCW_MIO_14_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_14_PULLUP {enabled} \
   CONFIG.PCW_MIO_14_SLEW {slow} \
   CONFIG.PCW_MIO_15_DIRECTION {inout} \
   CONFIG.PCW_MIO_15_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_15_PULLUP {enabled} \
   CONFIG.PCW_MIO_15_SLEW {slow} \
   CONFIG.PCW_MIO_16_DIRECTION {inout} \
   CONFIG.PCW_MIO_16_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_16_PULLUP {enabled} \
   CONFIG.PCW_MIO_16_SLEW {slow} \
   CONFIG.PCW_MIO_17_DIRECTION {inout} \
   CONFIG.PCW_MIO_17_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_17_PULLUP {enabled} \
   CONFIG.PCW_MIO_17_SLEW {slow} \
   CONFIG.PCW_MIO_18_DIRECTION {inout} \
   CONFIG.PCW_MIO_18_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_18_PULLUP {enabled} \
   CONFIG.PCW_MIO_18_SLEW {slow} \
   CONFIG.PCW_MIO_19_DIRECTION {inout} \
   CONFIG.PCW_MIO_19_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_19_PULLUP {enabled} \
   CONFIG.PCW_MIO_19_SLEW {slow} \
   CONFIG.PCW_MIO_1_DIRECTION {out} \
   CONFIG.PCW_MIO_1_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_1_PULLUP {disabled} \
   CONFIG.PCW_MIO_1_SLEW {slow} \
   CONFIG.PCW_MIO_20_DIRECTION {inout} \
   CONFIG.PCW_MIO_20_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_20_PULLUP {enabled} \
   CONFIG.PCW_MIO_20_SLEW {slow} \
   CONFIG.PCW_MIO_21_DIRECTION {inout} \
   CONFIG.PCW_MIO_21_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_21_PULLUP {enabled} \
   CONFIG.PCW_MIO_21_SLEW {slow} \
   CONFIG.PCW_MIO_22_DIRECTION {inout} \
   CONFIG.PCW_MIO_22_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_22_PULLUP {enabled} \
   CONFIG.PCW_MIO_22_SLEW {slow} \
   CONFIG.PCW_MIO_23_DIRECTION {inout} \
   CONFIG.PCW_MIO_23_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_23_PULLUP {enabled} \
   CONFIG.PCW_MIO_23_SLEW {slow} \
   CONFIG.PCW_MIO_24_DIRECTION {in} \
   CONFIG.PCW_MIO_24_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_24_PULLUP {enabled} \
   CONFIG.PCW_MIO_24_SLEW {slow} \
   CONFIG.PCW_MIO_25_DIRECTION {inout} \
   CONFIG.PCW_MIO_25_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_25_PULLUP {disabled} \
   CONFIG.PCW_MIO_25_SLEW {slow} \
   CONFIG.PCW_MIO_26_DIRECTION {in} \
   CONFIG.PCW_MIO_26_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_26_PULLUP {enabled} \
   CONFIG.PCW_MIO_26_SLEW {slow} \
   CONFIG.PCW_MIO_27_DIRECTION {out} \
   CONFIG.PCW_MIO_27_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_27_PULLUP {disabled} \
   CONFIG.PCW_MIO_27_SLEW {slow} \
   CONFIG.PCW_MIO_28_DIRECTION {inout} \
   CONFIG.PCW_MIO_28_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_28_PULLUP {disabled} \
   CONFIG.PCW_MIO_28_SLEW {fast} \
   CONFIG.PCW_MIO_29_DIRECTION {in} \
   CONFIG.PCW_MIO_29_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_29_PULLUP {disabled} \
   CONFIG.PCW_MIO_29_SLEW {fast} \
   CONFIG.PCW_MIO_2_DIRECTION {inout} \
   CONFIG.PCW_MIO_2_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_2_PULLUP {disabled} \
   CONFIG.PCW_MIO_2_SLEW {slow} \
   CONFIG.PCW_MIO_30_DIRECTION {out} \
   CONFIG.PCW_MIO_30_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_30_PULLUP {disabled} \
   CONFIG.PCW_MIO_30_SLEW {fast} \
   CONFIG.PCW_MIO_31_DIRECTION {in} \
   CONFIG.PCW_MIO_31_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_31_PULLUP {disabled} \
   CONFIG.PCW_MIO_31_SLEW {fast} \
   CONFIG.PCW_MIO_32_DIRECTION {inout} \
   CONFIG.PCW_MIO_32_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_32_PULLUP {disabled} \
   CONFIG.PCW_MIO_32_SLEW {fast} \
   CONFIG.PCW_MIO_33_DIRECTION {inout} \
   CONFIG.PCW_MIO_33_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_33_PULLUP {disabled} \
   CONFIG.PCW_MIO_33_SLEW {fast} \
   CONFIG.PCW_MIO_34_DIRECTION {inout} \
   CONFIG.PCW_MIO_34_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_34_PULLUP {disabled} \
   CONFIG.PCW_MIO_34_SLEW {fast} \
   CONFIG.PCW_MIO_35_DIRECTION {inout} \
   CONFIG.PCW_MIO_35_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_35_PULLUP {disabled} \
   CONFIG.PCW_MIO_35_SLEW {fast} \
   CONFIG.PCW_MIO_36_DIRECTION {in} \
   CONFIG.PCW_MIO_36_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_36_PULLUP {disabled} \
   CONFIG.PCW_MIO_36_SLEW {fast} \
   CONFIG.PCW_MIO_37_DIRECTION {inout} \
   CONFIG.PCW_MIO_37_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_37_PULLUP {disabled} \
   CONFIG.PCW_MIO_37_SLEW {fast} \
   CONFIG.PCW_MIO_38_DIRECTION {inout} \
   CONFIG.PCW_MIO_38_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_38_PULLUP {disabled} \
   CONFIG.PCW_MIO_38_SLEW {fast} \
   CONFIG.PCW_MIO_39_DIRECTION {inout} \
   CONFIG.PCW_MIO_39_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_39_PULLUP {disabled} \
   CONFIG.PCW_MIO_39_SLEW {fast} \
   CONFIG.PCW_MIO_3_DIRECTION {inout} \
   CONFIG.PCW_MIO_3_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_3_PULLUP {disabled} \
   CONFIG.PCW_MIO_3_SLEW {slow} \
   CONFIG.PCW_MIO_40_DIRECTION {inout} \
   CONFIG.PCW_MIO_40_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_40_PULLUP {disabled} \
   CONFIG.PCW_MIO_40_SLEW {fast} \
   CONFIG.PCW_MIO_41_DIRECTION {inout} \
   CONFIG.PCW_MIO_41_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_41_PULLUP {disabled} \
   CONFIG.PCW_MIO_41_SLEW {fast} \
   CONFIG.PCW_MIO_42_DIRECTION {inout} \
   CONFIG.PCW_MIO_42_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_42_PULLUP {disabled} \
   CONFIG.PCW_MIO_42_SLEW {fast} \
   CONFIG.PCW_MIO_43_DIRECTION {inout} \
   CONFIG.PCW_MIO_43_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_43_PULLUP {disabled} \
   CONFIG.PCW_MIO_43_SLEW {fast} \
   CONFIG.PCW_MIO_44_DIRECTION {inout} \
   CONFIG.PCW_MIO_44_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_44_PULLUP {disabled} \
   CONFIG.PCW_MIO_44_SLEW {fast} \
   CONFIG.PCW_MIO_45_DIRECTION {inout} \
   CONFIG.PCW_MIO_45_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_45_PULLUP {disabled} \
   CONFIG.PCW_MIO_45_SLEW {fast} \
   CONFIG.PCW_MIO_46_DIRECTION {in} \
   CONFIG.PCW_MIO_46_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_46_PULLUP {enabled} \
   CONFIG.PCW_MIO_46_SLEW {slow} \
   CONFIG.PCW_MIO_47_DIRECTION {out} \
   CONFIG.PCW_MIO_47_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_47_PULLUP {enabled} \
   CONFIG.PCW_MIO_47_SLEW {slow} \
   CONFIG.PCW_MIO_48_DIRECTION {in} \
   CONFIG.PCW_MIO_48_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_48_PULLUP {enabled} \
   CONFIG.PCW_MIO_48_SLEW {slow} \
   CONFIG.PCW_MIO_49_DIRECTION {in} \
   CONFIG.PCW_MIO_49_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_49_PULLUP {enabled} \
   CONFIG.PCW_MIO_49_SLEW {slow} \
   CONFIG.PCW_MIO_4_DIRECTION {inout} \
   CONFIG.PCW_MIO_4_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_4_PULLUP {disabled} \
   CONFIG.PCW_MIO_4_SLEW {slow} \
   CONFIG.PCW_MIO_50_DIRECTION {inout} \
   CONFIG.PCW_MIO_50_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_50_PULLUP {enabled} \
   CONFIG.PCW_MIO_50_SLEW {slow} \
   CONFIG.PCW_MIO_51_DIRECTION {inout} \
   CONFIG.PCW_MIO_51_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_51_PULLUP {enabled} \
   CONFIG.PCW_MIO_51_SLEW {slow} \
   CONFIG.PCW_MIO_52_DIRECTION {inout} \
   CONFIG.PCW_MIO_52_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_52_PULLUP {enabled} \
   CONFIG.PCW_MIO_52_SLEW {slow} \
   CONFIG.PCW_MIO_53_DIRECTION {inout} \
   CONFIG.PCW_MIO_53_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_53_PULLUP {enabled} \
   CONFIG.PCW_MIO_53_SLEW {slow} \
   CONFIG.PCW_MIO_5_DIRECTION {inout} \
   CONFIG.PCW_MIO_5_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_5_PULLUP {disabled} \
   CONFIG.PCW_MIO_5_SLEW {slow} \
   CONFIG.PCW_MIO_6_DIRECTION {out} \
   CONFIG.PCW_MIO_6_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_6_PULLUP {disabled} \
   CONFIG.PCW_MIO_6_SLEW {slow} \
   CONFIG.PCW_MIO_7_DIRECTION {out} \
   CONFIG.PCW_MIO_7_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_7_PULLUP {disabled} \
   CONFIG.PCW_MIO_7_SLEW {slow} \
   CONFIG.PCW_MIO_8_DIRECTION {out} \
   CONFIG.PCW_MIO_8_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_8_PULLUP {disabled} \
   CONFIG.PCW_MIO_8_SLEW {slow} \
   CONFIG.PCW_MIO_9_DIRECTION {inout} \
   CONFIG.PCW_MIO_9_IOTYPE {LVCMOS 1.8V} \
   CONFIG.PCW_MIO_9_PULLUP {enabled} \
   CONFIG.PCW_MIO_9_SLEW {slow} \
   CONFIG.PCW_MIO_TREE_PERIPHERALS {GPIO#Quad SPI Flash#Quad SPI Flash#Quad SPI Flash#Quad SPI Flash#Quad SPI Flash#Quad SPI Flash#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#GPIO#SD 0#GPIO#UART 0#UART 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#USB 0#SD 0#SD 0#SD 0#SD 0#SD 0#SD 0#PJTAG#PJTAG#PJTAG#PJTAG#I2C 0#I2C 0#I2C 1#I2C 1} \
   CONFIG.PCW_MIO_TREE_SIGNALS {gpio[0]#qspi0_ss_b#qspi0_io[0]#qspi0_io[1]#qspi0_io[2]#qspi0_io[3]/HOLD_B#qspi0_sclk#gpio[7]#gpio[8]#gpio[9]#gpio[10]#gpio[11]#gpio[12]#gpio[13]#gpio[14]#gpio[15]#gpio[16]#gpio[17]#gpio[18]#gpio[19]#gpio[20]#gpio[21]#gpio[22]#gpio[23]#cd#gpio[25]#rx#tx#data[4]#dir#stp#nxt#data[0]#data[1]#data[2]#data[3]#clk#data[5]#data[6]#data[7]#clk#cmd#data[0]#data[1]#data[2]#data[3]#tdi#tdo#tck#tms#scl#sda#scl#sda} \
   CONFIG.PCW_NAND_GRP_D8_ENABLE {0} \
   CONFIG.PCW_NAND_PERIPHERAL_ENABLE {0} \
   CONFIG.PCW_NOR_GRP_A25_ENABLE {0} \
   CONFIG.PCW_NOR_GRP_CS0_ENABLE {0} \
   CONFIG.PCW_NOR_GRP_CS1_ENABLE {0} \
   CONFIG.PCW_NOR_GRP_SRAM_CS0_ENABLE {0} \
   CONFIG.PCW_NOR_GRP_SRAM_CS1_ENABLE {0} \
   CONFIG.PCW_NOR_GRP_SRAM_INT_ENABLE {0} \
   CONFIG.PCW_NOR_PERIPHERAL_ENABLE {0} \
   CONFIG.PCW_PCAP_PERIPHERAL_DIVISOR0 {6} \
   CONFIG.PCW_PJTAG_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_PJTAG_PJTAG_IO {MIO 46 .. 49} \
   CONFIG.PCW_PRESET_BANK0_VOLTAGE {LVCMOS 1.8V} \
   CONFIG.PCW_PRESET_BANK1_VOLTAGE {LVCMOS 1.8V} \
   CONFIG.PCW_QSPI_GRP_FBCLK_ENABLE {0} \
   CONFIG.PCW_QSPI_GRP_IO1_ENABLE {0} \
   CONFIG.PCW_QSPI_GRP_SINGLE_SS_ENABLE {1} \
   CONFIG.PCW_QSPI_GRP_SINGLE_SS_IO {MIO 1 .. 6} \
   CONFIG.PCW_QSPI_GRP_SS1_ENABLE {0} \
   CONFIG.PCW_QSPI_PERIPHERAL_DIVISOR0 {6} \
   CONFIG.PCW_QSPI_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_QSPI_PERIPHERAL_FREQMHZ {200} \
   CONFIG.PCW_QSPI_QSPI_IO {MIO 1 .. 6} \
   CONFIG.PCW_SD0_GRP_CD_ENABLE {1} \
   CONFIG.PCW_SD0_GRP_CD_IO {MIO 24} \
   CONFIG.PCW_SD0_GRP_POW_ENABLE {0} \
   CONFIG.PCW_SD0_GRP_WP_ENABLE {0} \
   CONFIG.PCW_SD0_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_SD0_SD0_IO {MIO 40 .. 45} \
   CONFIG.PCW_SD1_GRP_CD_ENABLE {0} \
   CONFIG.PCW_SD1_GRP_POW_ENABLE {0} \
   CONFIG.PCW_SD1_GRP_WP_ENABLE {0} \
   CONFIG.PCW_SD1_PERIPHERAL_ENABLE {0} \
   CONFIG.PCW_SDIO_PERIPHERAL_DIVISOR0 {24} \
   CONFIG.PCW_SDIO_PERIPHERAL_FREQMHZ {50} \
   CONFIG.PCW_SDIO_PERIPHERAL_VALID {1} \
   CONFIG.PCW_SINGLE_QSPI_DATA_MODE {x4} \
   CONFIG.PCW_SMC_PERIPHERAL_DIVISOR0 {1} \
   CONFIG.PCW_SPI0_GRP_SS0_ENABLE {1} \
   CONFIG.PCW_SPI0_GRP_SS0_IO {EMIO} \
   CONFIG.PCW_SPI0_GRP_SS1_ENABLE {1} \
   CONFIG.PCW_SPI0_GRP_SS1_IO {EMIO} \
   CONFIG.PCW_SPI0_GRP_SS2_ENABLE {1} \
   CONFIG.PCW_SPI0_GRP_SS2_IO {EMIO} \
   CONFIG.PCW_SPI0_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_SPI0_SPI0_IO {EMIO} \
   CONFIG.PCW_SPI1_GRP_SS0_ENABLE {0} \
   CONFIG.PCW_SPI1_GRP_SS1_ENABLE {0} \
   CONFIG.PCW_SPI1_GRP_SS2_ENABLE {0} \
   CONFIG.PCW_SPI1_PERIPHERAL_ENABLE {0} \
   CONFIG.PCW_SPI_PERIPHERAL_CLKSRC {IO PLL} \
   CONFIG.PCW_SPI_PERIPHERAL_DIVISOR0 {6} \
   CONFIG.PCW_SPI_PERIPHERAL_FREQMHZ {200} \
   CONFIG.PCW_SPI_PERIPHERAL_VALID {1} \
   CONFIG.PCW_TPIU_PERIPHERAL_DIVISOR0 {1} \
   CONFIG.PCW_TTC0_CLK0_PERIPHERAL_FREQMHZ {133.333333} \
   CONFIG.PCW_TTC0_CLK1_PERIPHERAL_FREQMHZ {133.333333} \
   CONFIG.PCW_TTC0_CLK2_PERIPHERAL_FREQMHZ {133.333333} \
   CONFIG.PCW_TTC0_PERIPHERAL_ENABLE {0} \
   CONFIG.PCW_UART0_GRP_FULL_ENABLE {0} \
   CONFIG.PCW_UART0_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_UART0_UART0_IO {MIO 26 .. 27} \
   CONFIG.PCW_UART1_GRP_FULL_ENABLE {1} \
   CONFIG.PCW_UART1_GRP_FULL_IO {EMIO} \
   CONFIG.PCW_UART1_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_UART1_UART1_IO {EMIO} \
   CONFIG.PCW_UART_PERIPHERAL_DIVISOR0 {12} \
   CONFIG.PCW_UART_PERIPHERAL_FREQMHZ {100} \
   CONFIG.PCW_UART_PERIPHERAL_VALID {1} \
   CONFIG.PCW_UIPARAM_ACT_DDR_FREQ_MHZ {533.333374} \
   CONFIG.PCW_UIPARAM_DDR_BANK_ADDR_COUNT {3} \
   CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY0 {0.191} \
   CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY1 {0.209} \
   CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY2 {0.256} \
   CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY3 {0.228} \
   CONFIG.PCW_UIPARAM_DDR_CL {7} \
   CONFIG.PCW_UIPARAM_DDR_COL_ADDR_COUNT {10} \
   CONFIG.PCW_UIPARAM_DDR_CWL {6} \
   CONFIG.PCW_UIPARAM_DDR_DEVICE_CAPACITY {4096 MBits} \
   CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_0 {0.118} \
   CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_2 {0.182} \
   CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_3 {0.237} \
   CONFIG.PCW_UIPARAM_DDR_DRAM_WIDTH {16 Bits} \
   CONFIG.PCW_UIPARAM_DDR_PARTNO {MT41K256M16 RE-125} \
   CONFIG.PCW_UIPARAM_DDR_ROW_ADDR_COUNT {15} \
   CONFIG.PCW_UIPARAM_DDR_SPEED_BIN {DDR3_1066F} \
   CONFIG.PCW_UIPARAM_DDR_T_FAW {40.0} \
   CONFIG.PCW_UIPARAM_DDR_T_RAS_MIN {35.0} \
   CONFIG.PCW_UIPARAM_DDR_T_RC {48.75} \
   CONFIG.PCW_UIPARAM_DDR_T_RCD {7} \
   CONFIG.PCW_UIPARAM_DDR_T_RP {7} \
   CONFIG.PCW_USB0_PERIPHERAL_ENABLE {1} \
   CONFIG.PCW_USB0_PERIPHERAL_FREQMHZ {60} \
   CONFIG.PCW_USB0_RESET_ENABLE {0} \
   CONFIG.PCW_USB0_USB0_IO {MIO 28 .. 39} \
   CONFIG.PCW_USB1_RESET_ENABLE {0} \
   CONFIG.PCW_USB_RESET_ENABLE {1} \
   CONFIG.PCW_USB_RESET_SELECT {Share reset pin} \
   CONFIG.PCW_USE_DMA0 {1} \
   CONFIG.PCW_USE_FABRIC_INTERRUPT {1} \
   CONFIG.PCW_USE_M_AXI_GP0 {1} \
   CONFIG.PCW_USE_S_AXI_HP0 {1} \
   CONFIG.PCW_USE_S_AXI_HP1 {1} \
   CONFIG.PCW_USE_S_AXI_HP2 {1} \
 ] $processing_system7_1

  # Create instance: processing_system7_1_axi_periph, and set properties
  set processing_system7_1_axi_periph [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect processing_system7_1_axi_periph ]
  set_property -dict [ list \
   CONFIG.NUM_MI {9} \
 ] $processing_system7_1_axi_periph

  # Create instance: rst_processing_system7_1_152M, and set properties
  set rst_processing_system7_1_152M [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset rst_processing_system7_1_152M ]

  # Create instance: util_vector_logic_leds, and set properties
  set util_vector_logic_leds [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_leds ]
  set_property -dict [ list \
   CONFIG.C_OPERATION {or} \
   CONFIG.C_SIZE {5} \
   CONFIG.LOGO_FILE {data/sym_orgate.png} \
 ] $util_vector_logic_leds

  # Create instance: xlconcat_0, and set properties
  set xlconcat_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_0 ]
  set_property -dict [ list \
   CONFIG.NUM_PORTS {16} \
 ] $xlconcat_0

  # Create instance: xlconcat_2, and set properties
  set xlconcat_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_2 ]
  set_property -dict [ list \
   CONFIG.NUM_PORTS {32} \
 ] $xlconcat_2

  # Create instance: xlslice_5, and set properties
  set xlslice_5 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_5 ]
  set_property -dict [ list \
   CONFIG.DIN_FROM {26} \
   CONFIG.DIN_TO {26} \
   CONFIG.DIN_WIDTH {27} \
   CONFIG.DOUT_WIDTH {1} \
 ] $xlslice_5

  # Create instance: xlslice_6, and set properties
  set xlslice_6 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_6 ]
  set_property -dict [ list \
   CONFIG.DIN_FROM {1} \
   CONFIG.DIN_TO {1} \
   CONFIG.DOUT_WIDTH {1} \
 ] $xlslice_6

  # Create instance: xlslice_leds, and set properties
  set xlslice_leds [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_leds ]
  set_property -dict [ list \
   CONFIG.DIN_FROM {20} \
   CONFIG.DIN_TO {16} \
   CONFIG.DOUT_WIDTH {5} \
 ] $xlslice_leds

  # Create instance: xlslice_pmod2_ns9, and set properties
  set xlslice_pmod2_ns9 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_pmod2_ns9 ]
  set_property -dict [ list \
   CONFIG.DIN_FROM {30} \
   CONFIG.DIN_TO {30} \
 ] $xlslice_pmod2_ns9

  # Create instance: xlslice_pmod2_ns10, and set properties
  set xlslice_pmod2_ns10 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_pmod2_ns10 ]
  set_property -dict [ list \
   CONFIG.DIN_FROM {31} \
   CONFIG.DIN_TO {31} \
 ] $xlslice_pmod2_ns10

  # Create instance: xlslice_pmod2_rst, and set properties
  set xlslice_pmod2_rst [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_pmod2_rst ]
  set_property -dict [ list \
   CONFIG.DIN_FROM {29} \
   CONFIG.DIN_TO {29} \
 ] $xlslice_pmod2_rst

  # Create interface connections
  connect_bd_intf_net -intf_net axi_dmac_0_m_dest_axi [get_bd_intf_pins axi_dmac_0/m_dest_axi] [get_bd_intf_pins axi_mem_intercon_1/S01_AXI]
  connect_bd_intf_net -intf_net axi_gpio_0_GPIO2 [get_bd_intf_ports PMODs] [get_bd_intf_pins axi_gpio_0/GPIO2]
  connect_bd_intf_net -intf_net axi_mem_intercon_1_M00_AXI [get_bd_intf_pins axi_mem_intercon_1/M00_AXI] [get_bd_intf_pins processing_system7_1/S_AXI_HP1]
  connect_bd_intf_net -intf_net axi_mem_intercon_2_M00_AXI [get_bd_intf_pins axi_mem_intercon_2/M00_AXI] [get_bd_intf_pins processing_system7_1/S_AXI_HP2]
  connect_bd_intf_net -intf_net axi_mem_intercon_M00_AXI [get_bd_intf_pins axi_mem_intercon/M00_AXI] [get_bd_intf_pins processing_system7_1/S_AXI_HP0]
  connect_bd_intf_net -intf_net axi_vdma_0_M_AXI_MM2S [get_bd_intf_pins axi_mem_intercon/S00_AXI] [get_bd_intf_pins axi_vdma_0/M_AXI_MM2S]
  connect_bd_intf_net -intf_net axi_vdma_1_M_AXI_MM2S [get_bd_intf_pins axi_mem_intercon_1/S00_AXI] [get_bd_intf_pins axi_vdma_1/M_AXI_MM2S]
  connect_bd_intf_net -intf_net dyplo_axi_0_M_AXI_0 [get_bd_intf_pins axi_mem_intercon_2/S00_AXI] [get_bd_intf_pins dyplo_axi_0/M_AXI_0]
  connect_bd_intf_net -intf_net gmii_to_rgmii_0_MDIO_PHY [get_bd_intf_ports MDIO_PHY] [get_bd_intf_pins gmii_to_rgmii_0/MDIO_PHY]
  connect_bd_intf_net -intf_net gmii_to_rgmii_0_RGMII [get_bd_intf_ports RGMII] [get_bd_intf_pins gmii_to_rgmii_0/RGMII]
  connect_bd_intf_net -intf_net processing_system7_1_GMII_ETHERNET_0 [get_bd_intf_pins gmii_to_rgmii_0/GMII] [get_bd_intf_pins processing_system7_1/GMII_ETHERNET_0]
  connect_bd_intf_net -intf_net processing_system7_1_MDIO_ETHERNET_0 [get_bd_intf_pins gmii_to_rgmii_0/MDIO_GEM] [get_bd_intf_pins processing_system7_1/MDIO_ETHERNET_0]
  connect_bd_intf_net -intf_net processing_system7_1_M_AXI_GP0 [get_bd_intf_pins processing_system7_1/M_AXI_GP0] [get_bd_intf_pins processing_system7_1_axi_periph/S00_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_axi_periph_M00_AXI [get_bd_intf_pins axi_hdmi_rx_0/s_axi] [get_bd_intf_pins processing_system7_1_axi_periph/M00_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_axi_periph_M01_AXI [get_bd_intf_pins axi_vdma_1/S_AXI_LITE] [get_bd_intf_pins processing_system7_1_axi_periph/M01_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_axi_periph_M02_AXI [get_bd_intf_pins axis_2_lcd_0/S_AXI] [get_bd_intf_pins processing_system7_1_axi_periph/M02_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_axi_periph_M03_AXI [get_bd_intf_pins axi_gpio_0/S_AXI] [get_bd_intf_pins processing_system7_1_axi_periph/M03_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_axi_periph_M04_AXI [get_bd_intf_pins axi_spdif_tx_0/S_AXI] [get_bd_intf_pins processing_system7_1_axi_periph/M04_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_axi_periph_M05_AXI [get_bd_intf_pins axi_hdmi_tx_0/s_axi] [get_bd_intf_pins processing_system7_1_axi_periph/M05_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_axi_periph_M06_AXI [get_bd_intf_pins axi_vdma_0/S_AXI_LITE] [get_bd_intf_pins processing_system7_1_axi_periph/M06_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_axi_periph_M07_AXI [get_bd_intf_pins axi_dmac_0/s_axi] [get_bd_intf_pins processing_system7_1_axi_periph/M07_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_axi_periph_M08_AXI [get_bd_intf_pins dyplo_axi_0/S_AXI] [get_bd_intf_pins processing_system7_1_axi_periph/M08_AXI]
  connect_bd_intf_net -intf_net processing_system7_1_ddr [get_bd_intf_ports DDR] [get_bd_intf_pins processing_system7_1/DDR]
  connect_bd_intf_net -intf_net processing_system7_1_fixed_io [get_bd_intf_ports FIXED_IO] [get_bd_intf_pins processing_system7_1/FIXED_IO]

  # Create port connections
  connect_bd_net -net CLK125_NDO_1 [get_bd_ports CLK125_NDO] [get_bd_pins c_counter_binary_0/CLK]
  connect_bd_net -net UART1_CTSN_1 [get_bd_ports UART1_CTSN] [get_bd_pins processing_system7_1/UART1_CTSN]
  connect_bd_net -net UART1_RX_1 [get_bd_ports UART1_RX] [get_bd_pins processing_system7_1/UART1_RX]
  connect_bd_net -net axi_dmac_0_fifo_wr_overflow [get_bd_pins axi_dmac_0/fifo_wr_overflow] [get_bd_pins axi_hdmi_rx_0/hdmi_dma_ovf]
  connect_bd_net -net axi_dmac_0_irq [get_bd_pins axi_dmac_0/irq] [get_bd_pins xlconcat_0/In14]
  connect_bd_net -net axi_gpio_0_gpio_io_o [get_bd_pins axi_gpio_0/gpio_io_o] [get_bd_pins util_vector_logic_leds/Op1]
  connect_bd_net -net axi_hdmi_rx_0_hdmi_clk [get_bd_pins axi_dmac_0/fifo_wr_clk] [get_bd_pins axi_hdmi_rx_0/hdmi_clk]
  connect_bd_net -net axi_hdmi_rx_0_hdmi_dma_data [get_bd_pins axi_dmac_0/fifo_wr_din] [get_bd_pins axi_hdmi_rx_0/hdmi_dma_data]
  connect_bd_net -net axi_hdmi_rx_0_hdmi_dma_de [get_bd_pins axi_dmac_0/fifo_wr_en] [get_bd_pins axi_hdmi_rx_0/hdmi_dma_de]
  connect_bd_net -net axi_hdmi_rx_0_hdmi_dma_sof [get_bd_pins axi_dmac_0/fifo_wr_sync] [get_bd_pins axi_hdmi_rx_0/hdmi_dma_sof]
  connect_bd_net -net axi_hdmi_tx_0_hdmi_24_data [get_bd_ports hdmi_out_data] [get_bd_pins axi_hdmi_tx_0/hdmi_24_data]
  connect_bd_net -net axi_hdmi_tx_0_hdmi_24_data_e [get_bd_ports hdmi_out_de] [get_bd_pins axi_hdmi_tx_0/hdmi_24_data_e]
  connect_bd_net -net axi_hdmi_tx_0_hdmi_24_hsync [get_bd_ports hdmi_out_hs] [get_bd_pins axi_hdmi_tx_0/hdmi_24_hsync]
  connect_bd_net -net axi_hdmi_tx_0_hdmi_24_vsync [get_bd_ports hdmi_out_vs] [get_bd_pins axi_hdmi_tx_0/hdmi_24_vsync]
  connect_bd_net -net axi_hdmi_tx_0_m_axis_mm2s_fsync [get_bd_pins axi_hdmi_tx_0/m_axis_mm2s_fsync] [get_bd_pins axi_hdmi_tx_0/m_axis_mm2s_fsync_ret] [get_bd_pins axi_vdma_0/mm2s_fsync]
  connect_bd_net -net axi_hdmi_tx_0_m_axis_mm2s_tready [get_bd_pins axi_hdmi_tx_0/m_axis_mm2s_tready] [get_bd_pins axi_vdma_0/m_axis_mm2s_tready]
  connect_bd_net -net axi_spdif_tx_0_DMA_REQ_DAREADY [get_bd_pins axi_spdif_tx_0/DMA_REQ_DAREADY] [get_bd_pins processing_system7_1/DMA0_DAREADY]
  connect_bd_net -net axi_spdif_tx_0_DMA_REQ_DRLAST [get_bd_pins axi_spdif_tx_0/DMA_REQ_DRLAST] [get_bd_pins processing_system7_1/DMA0_DRLAST]
  connect_bd_net -net axi_spdif_tx_0_DMA_REQ_DRTYPE [get_bd_pins axi_spdif_tx_0/DMA_REQ_DRTYPE] [get_bd_pins processing_system7_1/DMA0_DRTYPE]
  connect_bd_net -net axi_spdif_tx_0_DMA_REQ_DRVALID [get_bd_pins axi_spdif_tx_0/DMA_REQ_DRVALID] [get_bd_pins processing_system7_1/DMA0_DRVALID]
  connect_bd_net -net axi_spdif_tx_0_spdif_tx_o [get_bd_ports hdmi_out_spdif] [get_bd_pins axi_spdif_tx_0/spdif_tx_o]
  connect_bd_net -net axi_vdma_0_m_axis_mm2s_tdata [get_bd_pins axi_hdmi_tx_0/m_axis_mm2s_tdata] [get_bd_pins axi_vdma_0/m_axis_mm2s_tdata]
  connect_bd_net -net axi_vdma_0_m_axis_mm2s_tkeep [get_bd_pins axi_hdmi_tx_0/m_axis_mm2s_tkeep] [get_bd_pins axi_vdma_0/m_axis_mm2s_tkeep]
  connect_bd_net -net axi_vdma_0_m_axis_mm2s_tlast [get_bd_pins axi_hdmi_tx_0/m_axis_mm2s_tlast] [get_bd_pins axi_vdma_0/m_axis_mm2s_tlast]
  connect_bd_net -net axi_vdma_0_m_axis_mm2s_tvalid [get_bd_pins axi_hdmi_tx_0/m_axis_mm2s_tvalid] [get_bd_pins axi_vdma_0/m_axis_mm2s_tvalid]
  connect_bd_net -net axi_vdma_0_mm2s_introut [get_bd_pins axi_vdma_0/mm2s_introut] [get_bd_pins xlconcat_0/In15]
  connect_bd_net -net axi_vdma_1_m_axis_mm2s_tdata [get_bd_pins axi_vdma_1/m_axis_mm2s_tdata] [get_bd_pins axis_2_lcd_0/S_AXIS_TDATA]
  connect_bd_net -net axi_vdma_1_m_axis_mm2s_tkeep [get_bd_pins axi_vdma_1/m_axis_mm2s_tkeep] [get_bd_pins axis_2_lcd_0/S_AXIS_TKEEP]
  connect_bd_net -net axi_vdma_1_m_axis_mm2s_tlast [get_bd_pins axi_vdma_1/m_axis_mm2s_tlast] [get_bd_pins axis_2_lcd_0/S_AXIS_TLAST]
  connect_bd_net -net axi_vdma_1_m_axis_mm2s_tuser [get_bd_pins axi_vdma_1/m_axis_mm2s_tuser] [get_bd_pins axis_2_lcd_0/S_AXIS_TUSER]
  connect_bd_net -net axi_vdma_1_m_axis_mm2s_tvalid [get_bd_pins axi_vdma_1/m_axis_mm2s_tvalid] [get_bd_pins axis_2_lcd_0/S_AXIS_TVALID]
  connect_bd_net -net axi_vdma_1_mm2s_introut [get_bd_pins axi_vdma_1/mm2s_introut] [get_bd_pins xlconcat_0/In11]
  connect_bd_net -net axis_2_lcd_0_S_AXIS_TREADY [get_bd_pins axi_vdma_1/m_axis_mm2s_tready] [get_bd_pins axis_2_lcd_0/S_AXIS_TREADY]
  connect_bd_net -net axis_2_lcd_0_backlight_en [get_bd_ports backlight_en] [get_bd_pins axis_2_lcd_0/backlight_en]
  connect_bd_net -net axis_2_lcd_0_backlight_pwm [get_bd_ports backlight_pwm] [get_bd_pins axis_2_lcd_0/backlight_pwm]
  connect_bd_net -net axis_2_lcd_0_lvds_channel_0_n [get_bd_ports lvds_channel_0_n] [get_bd_pins axis_2_lcd_0/lvds_channel_0_n]
  connect_bd_net -net axis_2_lcd_0_lvds_channel_0_p [get_bd_ports lvds_channel_0_p] [get_bd_pins axis_2_lcd_0/lvds_channel_0_p]
  connect_bd_net -net axis_2_lcd_0_lvds_channel_1_n [get_bd_ports lvds_channel_1_n] [get_bd_pins axis_2_lcd_0/lvds_channel_1_n]
  connect_bd_net -net axis_2_lcd_0_lvds_channel_1_p [get_bd_ports lvds_channel_1_p] [get_bd_pins axis_2_lcd_0/lvds_channel_1_p]
  connect_bd_net -net axis_2_lcd_0_lvds_channel_2_n [get_bd_ports lvds_channel_2_n] [get_bd_pins axis_2_lcd_0/lvds_channel_2_n]
  connect_bd_net -net axis_2_lcd_0_lvds_channel_2_p [get_bd_ports lvds_channel_2_p] [get_bd_pins axis_2_lcd_0/lvds_channel_2_p]
  connect_bd_net -net axis_2_lcd_0_lvds_clk_n [get_bd_ports lvds_clk_n] [get_bd_pins axis_2_lcd_0/lvds_clk_n]
  connect_bd_net -net axis_2_lcd_0_lvds_clk_p [get_bd_ports lvds_clk_p] [get_bd_pins axis_2_lcd_0/lvds_clk_p]
  connect_bd_net -net axis_2_lcd_0_mm2s_fsync [get_bd_pins axi_vdma_1/mm2s_fsync] [get_bd_pins axis_2_lcd_0/mm2s_fsync]
  connect_bd_net -net button_s2_1 [get_bd_ports button_s2] [get_bd_pins xlconcat_2/In4]
  connect_bd_net -net button_s3_1 [get_bd_ports button_s3] [get_bd_pins xlconcat_2/In5]
  connect_bd_net -net c_counter_binary_0_Q [get_bd_pins c_counter_binary_0/Q] [get_bd_pins xlslice_5/Din]
  connect_bd_net -net clk_wiz_0_clk_out1 [get_bd_pins axis_2_lcd_0/pixel_clk] [get_bd_pins clk_wiz_0/clk_out1]
  connect_bd_net -net clk_wiz_0_locked [get_bd_pins axis_2_lcd_0/pixel_clk_locked] [get_bd_pins clk_wiz_0/locked]
  connect_bd_net -net clock98mhz_1 [get_bd_ports clock98mhz] [get_bd_pins clk_wiz_0/clk_in1]
  connect_bd_net -net constant_one_dout [get_bd_pins constant_one/dout] [get_bd_pins processing_system7_1/SPI0_SS_I]
  connect_bd_net -net dyplo_axi_0_dyplo_irq [get_bd_pins dyplo_axi_0/dyplo_irq] [get_bd_pins xlconcat_0/In13]
  connect_bd_net -net eth_int_n_1 [get_bd_ports eth_int_n] [get_bd_pins xlconcat_2/In11]
  connect_bd_net -net hdmi_clk_1 [get_bd_ports cdce_y4_clk] [get_bd_ports hdmi_out_clk] [get_bd_pins axi_hdmi_tx_0/hdmi_clk]
  connect_bd_net -net hdmi_in_clk_1 [get_bd_ports hdmi_in_clk] [get_bd_pins axi_hdmi_rx_0/hdmi_rx_clk]
  connect_bd_net -net hdmi_in_data_1 [get_bd_ports hdmi_in_data] [get_bd_pins axi_hdmi_rx_0/hdmi_rx_data]
  connect_bd_net -net hdmi_in_de_1 [get_bd_ports hdmi_in_de] [get_bd_pins axi_hdmi_rx_0/hdmi_rx_de]
  connect_bd_net -net hdmi_in_hs_1 [get_bd_ports hdmi_in_hs] [get_bd_pins axi_hdmi_rx_0/hdmi_rx_hs]
  connect_bd_net -net hdmi_in_int_n_1 [get_bd_ports hdmi_in_int_n] [get_bd_pins xlconcat_2/In3]
  connect_bd_net -net hdmi_in_vs_1 [get_bd_ports hdmi_in_vs] [get_bd_pins axi_hdmi_rx_0/hdmi_rx_vs]
  connect_bd_net -net hdmi_out_spdif_clk_1 [get_bd_ports hdmi_out_spdif_clk] [get_bd_pins axi_spdif_tx_0/spdif_data_clk]
  connect_bd_net -net pmod2_int_1 [get_bd_ports pmod2_int] [get_bd_pins xlconcat_2/In24]
  connect_bd_net -net pmod2_spi_miso_1 [get_bd_ports pmod2_spi_miso] [get_bd_pins processing_system7_1/SPI0_MISO_I]
  connect_bd_net -net proc_sys_reset_interconnect_aresetn [get_bd_pins proc_sys_reset/interconnect_aresetn] [get_bd_pins processing_system7_1_axi_periph/ARESETN]
  connect_bd_net -net proc_sys_reset_peripheral_aresetn [get_bd_ports eth_reset_n] [get_bd_pins axi_dmac_0/s_axi_aresetn] [get_bd_pins axi_gpio_0/s_axi_aresetn] [get_bd_pins axi_hdmi_rx_0/s_axi_aresetn] [get_bd_pins axi_hdmi_tx_0/s_axi_aresetn] [get_bd_pins axi_spdif_tx_0/DMA_REQ_RSTN] [get_bd_pins axi_spdif_tx_0/S_AXI_ARESETN] [get_bd_pins axi_vdma_0/axi_resetn] [get_bd_pins axi_vdma_1/axi_resetn] [get_bd_pins axis_2_lcd_0/S_AXI_ARESETN] [get_bd_pins dyplo_axi_0/S_AXI_ARESETN] [get_bd_pins proc_sys_reset/peripheral_aresetn] [get_bd_pins processing_system7_1_axi_periph/M00_ARESETN] [get_bd_pins processing_system7_1_axi_periph/M01_ARESETN] [get_bd_pins processing_system7_1_axi_periph/M02_ARESETN] [get_bd_pins processing_system7_1_axi_periph/M03_ARESETN] [get_bd_pins processing_system7_1_axi_periph/M04_ARESETN] [get_bd_pins processing_system7_1_axi_periph/M05_ARESETN] [get_bd_pins processing_system7_1_axi_periph/M06_ARESETN] [get_bd_pins processing_system7_1_axi_periph/M07_ARESETN] [get_bd_pins processing_system7_1_axi_periph/M08_ARESETN] [get_bd_pins processing_system7_1_axi_periph/S00_ARESETN]
  connect_bd_net -net processing_system7_1_DMA0_DATYPE [get_bd_pins axi_spdif_tx_0/DMA_REQ_DATYPE] [get_bd_pins processing_system7_1/DMA0_DATYPE]
  connect_bd_net -net processing_system7_1_DMA0_DAVALID [get_bd_pins axi_spdif_tx_0/DMA_REQ_DAVALID] [get_bd_pins processing_system7_1/DMA0_DAVALID]
  connect_bd_net -net processing_system7_1_DMA0_DRREADY [get_bd_pins axi_spdif_tx_0/DMA_REQ_DRREADY] [get_bd_pins processing_system7_1/DMA0_DRREADY]
  connect_bd_net -net processing_system7_1_FCLK_CLK0 [get_bd_pins axi_dmac_0/s_axi_aclk] [get_bd_pins axi_gpio_0/s_axi_aclk] [get_bd_pins axi_hdmi_rx_0/s_axi_aclk] [get_bd_pins axi_hdmi_tx_0/s_axi_aclk] [get_bd_pins axi_spdif_tx_0/DMA_REQ_ACLK] [get_bd_pins axi_spdif_tx_0/S_AXI_ACLK] [get_bd_pins axi_vdma_0/s_axi_lite_aclk] [get_bd_pins axi_vdma_1/s_axi_lite_aclk] [get_bd_pins axis_2_lcd_0/S_AXI_ACLK] [get_bd_pins axis_2_lcd_0/pwm_clock] [get_bd_pins dyplo_axi_0/S_AXI_ACLK] [get_bd_pins dyplo_axi_0/dna_port_clk] [get_bd_pins proc_sys_reset/slowest_sync_clk] [get_bd_pins processing_system7_1/DMA0_ACLK] [get_bd_pins processing_system7_1/FCLK_CLK0] [get_bd_pins processing_system7_1/M_AXI_GP0_ACLK] [get_bd_pins processing_system7_1_axi_periph/ACLK] [get_bd_pins processing_system7_1_axi_periph/M00_ACLK] [get_bd_pins processing_system7_1_axi_periph/M01_ACLK] [get_bd_pins processing_system7_1_axi_periph/M02_ACLK] [get_bd_pins processing_system7_1_axi_periph/M03_ACLK] [get_bd_pins processing_system7_1_axi_periph/M04_ACLK] [get_bd_pins processing_system7_1_axi_periph/M05_ACLK] [get_bd_pins processing_system7_1_axi_periph/M06_ACLK] [get_bd_pins processing_system7_1_axi_periph/M07_ACLK] [get_bd_pins processing_system7_1_axi_periph/M08_ACLK] [get_bd_pins processing_system7_1_axi_periph/S00_ACLK]
  connect_bd_net -net processing_system7_1_FCLK_CLK1 [get_bd_pins axi_dmac_0/m_dest_axi_aclk] [get_bd_pins axi_hdmi_tx_0/m_axis_mm2s_clk] [get_bd_pins axi_mem_intercon/ACLK] [get_bd_pins axi_mem_intercon/M00_ACLK] [get_bd_pins axi_mem_intercon/S00_ACLK] [get_bd_pins axi_mem_intercon_1/ACLK] [get_bd_pins axi_mem_intercon_1/M00_ACLK] [get_bd_pins axi_mem_intercon_1/S00_ACLK] [get_bd_pins axi_mem_intercon_1/S01_ACLK] [get_bd_pins axi_mem_intercon_2/ACLK] [get_bd_pins axi_mem_intercon_2/M00_ACLK] [get_bd_pins axi_mem_intercon_2/S00_ACLK] [get_bd_pins axi_vdma_0/m_axi_mm2s_aclk] [get_bd_pins axi_vdma_0/m_axis_mm2s_aclk] [get_bd_pins axi_vdma_1/m_axi_mm2s_aclk] [get_bd_pins axi_vdma_1/m_axis_mm2s_aclk] [get_bd_pins axis_2_lcd_0/S_AXIS_ACLK] [get_bd_pins dyplo_axi_0/M_AXI_0_ACLK] [get_bd_pins dyplo_axi_0/dyplo_clock] [get_bd_pins processing_system7_1/FCLK_CLK1] [get_bd_pins processing_system7_1/S_AXI_HP0_ACLK] [get_bd_pins processing_system7_1/S_AXI_HP1_ACLK] [get_bd_pins processing_system7_1/S_AXI_HP2_ACLK] [get_bd_pins rst_processing_system7_1_152M/slowest_sync_clk]
  connect_bd_net -net processing_system7_1_FCLK_CLK2 [get_bd_pins gmii_to_rgmii_0/clkin] [get_bd_pins processing_system7_1/FCLK_CLK2]
  connect_bd_net -net processing_system7_1_FCLK_RESET0_N [get_bd_pins proc_sys_reset/ext_reset_in] [get_bd_pins processing_system7_1/FCLK_RESET0_N] [get_bd_pins rst_processing_system7_1_152M/ext_reset_in]
  connect_bd_net -net processing_system7_1_GPIO_O [get_bd_pins processing_system7_1/GPIO_O] [get_bd_pins xlslice_6/Din] [get_bd_pins xlslice_leds/Din] [get_bd_pins xlslice_pmod2_ns10/Din] [get_bd_pins xlslice_pmod2_ns9/Din] [get_bd_pins xlslice_pmod2_rst/Din]
  connect_bd_net -net processing_system7_1_SPI0_MOSI_O [get_bd_ports pmod2_spi_mosi] [get_bd_pins processing_system7_1/SPI0_MOSI_O]
  connect_bd_net -net processing_system7_1_SPI0_SCLK_O [get_bd_ports pmod2_spi_sck] [get_bd_pins processing_system7_1/SPI0_SCLK_O]
  connect_bd_net -net processing_system7_1_SPI0_SS_O [get_bd_ports pmod2_spi_ss] [get_bd_pins processing_system7_1/SPI0_SS_O]
  connect_bd_net -net processing_system7_1_UART1_RTSN [get_bd_ports UART1_RTSN] [get_bd_pins processing_system7_1/UART1_RTSN]
  connect_bd_net -net processing_system7_1_UART1_TX [get_bd_ports UART1_TX] [get_bd_pins processing_system7_1/UART1_TX]
  connect_bd_net -net rst_processing_system7_1_152M_interconnect_aresetn [get_bd_pins axi_mem_intercon/ARESETN] [get_bd_pins axi_mem_intercon_1/ARESETN] [get_bd_pins rst_processing_system7_1_152M/interconnect_aresetn]
  connect_bd_net -net rst_processing_system7_1_152M_peripheral_aresetn [get_bd_pins axi_dmac_0/m_dest_axi_aresetn] [get_bd_pins axi_mem_intercon/M00_ARESETN] [get_bd_pins axi_mem_intercon/S00_ARESETN] [get_bd_pins axi_mem_intercon_1/M00_ARESETN] [get_bd_pins axi_mem_intercon_1/S00_ARESETN] [get_bd_pins axi_mem_intercon_1/S01_ARESETN] [get_bd_pins axi_mem_intercon_2/ARESETN] [get_bd_pins axi_mem_intercon_2/M00_ARESETN] [get_bd_pins axi_mem_intercon_2/S00_ARESETN] [get_bd_pins axis_2_lcd_0/S_AXIS_ARESETN] [get_bd_pins dyplo_axi_0/M_AXI_0_ARESETN] [get_bd_pins rst_processing_system7_1_152M/peripheral_aresetn]
  connect_bd_net -net touch_irq_n_1 [get_bd_ports touch_irq_n] [get_bd_pins xlconcat_2/In10]
  connect_bd_net -net util_vector_logic_4_Res [get_bd_pins gmii_to_rgmii_0/rx_reset] [get_bd_pins gmii_to_rgmii_0/tx_reset] [get_bd_pins proc_sys_reset/peripheral_reset]
  connect_bd_net -net util_vector_logic_leds_Res [get_bd_ports LEDS] [get_bd_pins util_vector_logic_leds/Res] [get_bd_pins xlconcat_2/In16]
  connect_bd_net -net xlconcat_0_dout [get_bd_pins processing_system7_1/IRQ_F2P] [get_bd_pins xlconcat_0/dout]
  connect_bd_net -net xlconcat_2_dout [get_bd_pins processing_system7_1/GPIO_I] [get_bd_pins xlconcat_2/dout]
  connect_bd_net -net xlconstant_0_const [get_bd_pins axi_hdmi_rx_0/hdmi_dma_unf] [get_bd_pins clk_wiz_0/reset] [get_bd_pins gnd/dout] [get_bd_pins processing_system7_1/USB0_VBUS_PWRFAULT] [get_bd_pins xlconcat_0/In0] [get_bd_pins xlconcat_0/In1] [get_bd_pins xlconcat_0/In2] [get_bd_pins xlconcat_0/In3] [get_bd_pins xlconcat_0/In4] [get_bd_pins xlconcat_0/In5] [get_bd_pins xlconcat_0/In6] [get_bd_pins xlconcat_0/In7] [get_bd_pins xlconcat_0/In8] [get_bd_pins xlconcat_0/In9] [get_bd_pins xlconcat_0/In10] [get_bd_pins xlconcat_0/In12] [get_bd_pins xlconcat_2/In0] [get_bd_pins xlconcat_2/In2] [get_bd_pins xlconcat_2/In6] [get_bd_pins xlconcat_2/In7] [get_bd_pins xlconcat_2/In8] [get_bd_pins xlconcat_2/In9] [get_bd_pins xlconcat_2/In12] [get_bd_pins xlconcat_2/In13] [get_bd_pins xlconcat_2/In14] [get_bd_pins xlconcat_2/In15] [get_bd_pins xlconcat_2/In17] [get_bd_pins xlconcat_2/In18] [get_bd_pins xlconcat_2/In19] [get_bd_pins xlconcat_2/In20] [get_bd_pins xlconcat_2/In21] [get_bd_pins xlconcat_2/In22] [get_bd_pins xlconcat_2/In23]
  connect_bd_net -net xlslice_5_Dout [get_bd_ports user_led] [get_bd_pins xlslice_5/Dout]
  connect_bd_net -net xlslice_6_Dout [get_bd_ports hdmi_in_rst_n] [get_bd_pins xlconcat_2/In1] [get_bd_pins xlslice_6/Dout]
  connect_bd_net -net xlslice_leds_Dout [get_bd_pins util_vector_logic_leds/Op2] [get_bd_pins xlslice_leds/Dout]
  connect_bd_net -net xlslice_pmod2_ns10_Dout [get_bd_ports pmod2_ns10] [get_bd_pins xlconcat_2/In27] [get_bd_pins xlslice_pmod2_ns10/Dout]
  connect_bd_net -net xlslice_pmod2_ns9_Dout [get_bd_ports pmod2_ns9] [get_bd_pins xlconcat_2/In26] [get_bd_pins xlslice_pmod2_ns9/Dout]
  connect_bd_net -net xlslice_pmod2_rst_Dout [get_bd_ports pmod2_rst] [get_bd_pins xlconcat_2/In25] [get_bd_pins xlslice_pmod2_rst/Dout]

  # Create address segments
  assign_bd_address -offset 0x00000000 -range 0x40000000 -target_address_space [get_bd_addr_spaces axi_dmac_0/m_dest_axi] [get_bd_addr_segs processing_system7_1/S_AXI_HP1/HP1_DDR_LOWOCM] -force
  assign_bd_address -offset 0x00000000 -range 0x40000000 -target_address_space [get_bd_addr_spaces axi_vdma_0/Data_MM2S] [get_bd_addr_segs processing_system7_1/S_AXI_HP0/HP0_DDR_LOWOCM] -force
  assign_bd_address -offset 0x00000000 -range 0x40000000 -target_address_space [get_bd_addr_spaces axi_vdma_1/Data_MM2S] [get_bd_addr_segs processing_system7_1/S_AXI_HP1/HP1_DDR_LOWOCM] -force
  assign_bd_address -offset 0x00000000 -range 0x40000000 -target_address_space [get_bd_addr_spaces dyplo_axi_0/M_AXI_0] [get_bd_addr_segs processing_system7_1/S_AXI_HP2/HP2_DDR_LOWOCM] -force
  assign_bd_address -offset 0x43C00000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_1/Data] [get_bd_addr_segs axi_dmac_0/s_axi/axi_lite] -force
  assign_bd_address -offset 0x40000000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_1/Data] [get_bd_addr_segs axi_gpio_0/S_AXI/Reg] -force
  assign_bd_address -offset 0x43C10000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_1/Data] [get_bd_addr_segs axi_hdmi_rx_0/s_axi/axi_lite] -force
  assign_bd_address -offset 0x70E00000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_1/Data] [get_bd_addr_segs axi_hdmi_tx_0/s_axi/axi_lite] -force
  assign_bd_address -offset 0x75C00000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_1/Data] [get_bd_addr_segs axi_spdif_tx_0/S_AXI/reg0] -force
  assign_bd_address -offset 0x43000000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_1/Data] [get_bd_addr_segs axi_vdma_0/S_AXI_LITE/Reg] -force
  assign_bd_address -offset 0x43010000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_1/Data] [get_bd_addr_segs axi_vdma_1/S_AXI_LITE/Reg] -force
  assign_bd_address -offset 0x7E000000 -range 0x00010000 -target_address_space [get_bd_addr_spaces processing_system7_1/Data] [get_bd_addr_segs axis_2_lcd_0/S_AXI/reg0] -force
  assign_bd_address -offset 0x64400000 -range 0x00200000 -target_address_space [get_bd_addr_spaces processing_system7_1/Data] [get_bd_addr_segs dyplo_axi_0/S_AXI/reg0] -force


  # Restore current instance
  current_bd_instance $oldCurInst

  validate_bd_design
  save_bd_design
}
# End of create_root_design()


##################################################################
# MAIN FLOW
##################################################################

create_root_design ""


