######### HDMI IN timing constraints #############
##################################################
set input_clock            "hdmi_in_clk";
set input_clock_period     6.734;
set input_clock_waveform   {3.367 6.734};
set dv_bre                 [expr [expr 0.45 * $input_clock_period] - 0.3];    # Data valid before the rising clock edge
set dv_are                 [expr [expr 0.45 * $input_clock_period] - 2.2];    # Data valid after the rising clock edge
set input_ports            [get_ports -regexp -nocase {hdmi_in_(?!(clk|int|rst)).*}];

# Create clock
create_clock -period $input_clock_period -name $input_clock -waveform $input_clock_waveform [get_ports $input_clock]
# Input Delay Constraint
set_input_delay -clock "${input_clock}" -max [expr $input_clock_period - $dv_bre] [get_ports $input_ports];
set_input_delay -clock "${input_clock}" -min $dv_are                              [get_ports $input_ports];

# False path to HDMI-in negative edge clocking
set_false_path -to [get_cells -hierarchical -regexp {.*rx_core.*hdmi.*neg.*reg.*}]


######### HDMI OUT timing constraints ############
##################################################
set tsu          1.0;   # destination device setup time requirement
set thd          0.7;   # destination device hold time requirement
set output_ports [get_ports -regexp -nocase {hdmi_out_(?!(.*clk|.*spdif.*)).*}];

# Create forwarded (generated) clock
create_generated_clock -name hdmi_out_clk -source [get_pins tdkz_trd_i/cdce_y4_clk] -multiply_by 1 [get_ports "*hdmi_out_clk*"]

# Output Delay Constraints
set_output_delay -clock "hdmi_out_clk" -max $tsu [get_ports $output_ports];
set_output_delay -clock "hdmi_out_clk" -min $thd [get_ports $output_ports];

################# SET CLOCK GROUPS ###############
##################################################
set_clock_groups -asynchronous -group [get_clocks -include_generated_clocks -regexp {.*cdce_y4.*}]
set_clock_groups -asynchronous -group [get_clocks -include_generated_clocks -regexp {.*clk_fpga_0.*}]
set_clock_groups -asynchronous -group [get_clocks -include_generated_clocks -regexp {.*clk_fpga_1.*}]
set_clock_groups -asynchronous -group [get_clocks -include_generated_clocks -regexp {.*clk_fpga_2.*}]
set_clock_groups -asynchronous -group [get_clocks -include_generated_clocks -regexp {.*rgmii_rxc.*}]
set_clock_groups -asynchronous -group [get_clocks -include_generated_clocks -regexp {.*clk_out1.*}]

set_clock_groups -physically_exclusive -group [get_clocks -regexp {.*_25m.*}] -group [get_clocks -regexp {.*_2_5m.*}] -group [get_clocks -regexp {.*_125m.*}]

